@@ -86,6 +86,15 @@ LanPreferencesForm::LanPreferencesForm(
     ui->indicatorBrightnessComboBox->setCurrentIndex(ibl);
   }
 
+  if (settings.contains("CoverClosesApp"))
+  {
+    bool cca = settings.value("CoverClosesApp").toBool();
+
+    ui->closeAppCheckBox->setChecked(cca);
+
+    mainWindow->setCoverClosesApp(cca);
+  }
+
 /*
   if (settings.contains("DisableCameraApp"))
   {
@@ -131,6 +140,10 @@ LanPreferencesForm::~LanPreferencesForm()
     "IndicatorBrightnessLevel",
     ui->indicatorBrightnessComboBox->currentIndex());
 
+  settings.setValue(
+    "CoverClosesApp",
+    ui->closeAppCheckBox->isChecked());
+
 /*
   settings.setValue(
     "DisableCameraApp",
@@ -180,6 +193,12 @@ void LanPreferencesForm::on_indicatorBrightnessComboBox_currentIndexChanged(
 }
 
 
+void LanPreferencesForm::on_closeAppCheckBox_toggled(bool checked)
+{
+  mainWindow->setCoverClosesApp(checked);
+}
+
+
 /*
 void LanPreferencesForm::on_disableCameraCheckBox_toggled(
   bool checked)
